==> haskell-doctest-parallel-0.3.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-802ffAt0re5ITBaZx3GUMW
key:                  doctest-parallel-0.3.1-802ffAt0re5ITBaZx3GUMW
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  c279130e14f086d5b82fbb3d55427bbe
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-802ffAt0re5ITBaZx3GUMW
depends:
    Cabal-3.8.1.0 Glob-0.10.2-CfMdUOLNwWWADTihQDYGgB base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    random-1.2.1.2-9A7wjy4kMRRA6JvDfUzvpH
    syb-0.7.2.4-CLsCb1U1DGkGwwvmeMNNEv transformers-0.5.6.2
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-K8WzGEyVuTM7K2CibFLuun-spectests-modules

key:
    doctest-parallel-0.3.1-K8WzGEyVuTM7K2CibFLuun-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  fa08346fe45689a684918147cedef7bf
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-K8WzGEyVuTM7K2CibFLuun-spectests-modules

depends:
    base-4.17.2.1 doctest-parallel-0.3.1-802ffAt0re5ITBaZx3GUMW
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-parallel-0.3.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-JlHPohQTJyGbFKHoV8CWw
key:                  doctest-parallel-0.3.1-JlHPohQTJyGbFKHoV8CWw
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  729687956be14a08fd2331fd3ca49045
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-JlHPohQTJyGbFKHoV8CWw
depends:
    Cabal-3.8.1.0 Glob-0.10.2-3rJZMM8sM5hEmbHI5giFJh base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    random-1.2.1.3-CHWutlTevvFCu3tIK8p0Pr
    syb-0.7.2.4-GmxPZdaeeufLwFzHsnnj0g transformers-0.5.6.2
    unordered-containers-0.2.20-DP4QHaCUkq0wtUis18g4W

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-CSBwUKBpxzEEKedFMg9FCp-spectests-modules

key:
    doctest-parallel-0.3.1-CSBwUKBpxzEEKedFMg9FCp-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  6bb4a3736252278f1c0b3dc40dc23cb3
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-CSBwUKBpxzEEKedFMg9FCp-spectests-modules

depends:
    base-4.17.2.1 doctest-parallel-0.3.1-JlHPohQTJyGbFKHoV8CWw
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
